cli

package
v0.0.0-...-ae6e62c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 7, 2025 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	// Common flag names
	FlagLogLevel  = "log-level"
	FlagLogFormat = "log-format"

	// Temporal-specific flags
	FlagTemporalAddress   = "temporal-address"
	FlagTemporalNamespace = "temporal-namespace"
	FlagTemporalAPIKey    = "temporal-api-key"
	FlagTemporalTLSCert   = "temporal-tls-cert"
	FlagTemporalTLSKey    = "temporal-tls-key"

	// Zendesk-specific flags
	FlagZendeskSubdomain = "zendesk-subdomain"
	FlagZendeskEmail     = "zendesk-email"
	FlagZendeskToken     = "zendesk-token"

	// AI-specific flags
	FlagLLMProvider         = "llm-provider"
	FlagLLMModel            = "llm-model"
	FlagLLMAPIKey           = "llm-api-key"
	FlagTicketSummaryPrompt = "ticket-summary-prompt"
	FlagOrgSummaryPrompt    = "org-summary-prompt"
)
const (
	// Server-specific flags
	FlagServerHost            = "host"
	FlagServerPort            = "port"
	FlagServerAPIToken        = "server-api-token"
	FlagZendeskWebhookBaseURL = "zendesk-webhook-base-url"
)
const (
	// Worker-specific flags
	FlagWorkerQueue = "queue"
)
const (
	Version = "0.0.1"
)

Variables

This section is empty.

Functions

func NewServerApp

func NewServerApp(ctx *cli.Context) (*fx.App, error)

NewServerApp creates an fx application for the server command

func NewServerCommand

func NewServerCommand() *cli.Command

NewServerCommand creates a new server command with subcommands

func NewWorkerApp

func NewWorkerApp(ctx *cli.Context) (*fx.App, error)

NewWorkerApp creates an fx application for the worker command

func NewWorkerCommand

func NewWorkerCommand() *cli.Command

NewWorkerCommand creates a new worker command with subcommands

func NewWorkerConfig

func NewWorkerConfig(ctx *cli.Context) (config.WorkerConfig, error)

NewWorkerConfig creates a WorkerConfig from CLI context

func Run

func Run(args []string) error

Run parses CLI args and starts the appropriate fx application

Types

This section is empty.

Jump to