Documentation
¶
Index ¶
Constants ¶
const ( // Common flag names FlagLogLevel = "log-level" FlagLogFormat = "log-format" // Temporal-specific flags FlagTemporalAddress = "temporal-address" FlagTemporalNamespace = "temporal-namespace" FlagTemporalAPIKey = "temporal-api-key" FlagTemporalTLSCert = "temporal-tls-cert" FlagTemporalTLSKey = "temporal-tls-key" // Zendesk-specific flags FlagZendeskSubdomain = "zendesk-subdomain" FlagZendeskEmail = "zendesk-email" FlagZendeskToken = "zendesk-token" // AI-specific flags FlagLLMProvider = "llm-provider" FlagLLMModel = "llm-model" FlagLLMAPIKey = "llm-api-key" FlagTicketSummaryPrompt = "ticket-summary-prompt" FlagOrgSummaryPrompt = "org-summary-prompt" )
const ( // Server-specific flags FlagServerHost = "host" FlagServerPort = "port" FlagServerAPIToken = "server-api-token" FlagZendeskWebhookBaseURL = "zendesk-webhook-base-url" )
const (
// Worker-specific flags
FlagWorkerQueue = "queue"
)
const (
Version = "0.0.1"
)
Variables ¶
This section is empty.
Functions ¶
func NewServerApp ¶
NewServerApp creates an fx application for the server command
func NewServerCommand ¶
NewServerCommand creates a new server command with subcommands
func NewWorkerApp ¶
NewWorkerApp creates an fx application for the worker command
func NewWorkerCommand ¶
NewWorkerCommand creates a new worker command with subcommands
func NewWorkerConfig ¶
func NewWorkerConfig(ctx *cli.Context) (config.WorkerConfig, error)
NewWorkerConfig creates a WorkerConfig from CLI context
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.